summaryrefslogtreecommitdiffstats
path: root/src/moc
diff options
context:
space:
mode:
authorMichele Calgaro <[email protected]>2023-12-27 19:25:43 +0900
committerMichele Calgaro <[email protected]>2023-12-27 19:25:43 +0900
commitfb401a891f1b426e9419c0cb16403df407138611 (patch)
tree045b51949b3140039e37d898d8b0513016a86bea /src/moc
parenta9d178f1000475ba1727ffe123a2c54585488c01 (diff)
downloadtqt3-fb401a891f1b426e9419c0cb16403df407138611.tar.gz
tqt3-fb401a891f1b426e9419c0cb16403df407138611.zip
Rename METHOD, SIGNAL, SLOT to TQ_METHOD, TQ_SIGNAL, TQ_SLOT
Signed-off-by: Michele Calgaro <[email protected]>
Diffstat (limited to 'src/moc')
-rw-r--r--src/moc/moc.y4
-rw-r--r--src/moc/moc_yacc.cpp4
2 files changed, 4 insertions, 4 deletions
diff --git a/src/moc/moc.y b/src/moc/moc.y
index 86fd20dea..4b754b7bc 100644
--- a/src/moc/moc.y
+++ b/src/moc/moc.y
@@ -2134,7 +2134,7 @@ void registerClassInNamespace()
}
//
-// Remove white space from SIGNAL and SLOT names.
+// Remove white space from TQ_SIGNAL and TQ_SLOT names.
// This function has been copied from qobject.cpp.
//
@@ -3138,7 +3138,7 @@ void generateClass() // generate C++ source code for a class
fixRightAngles( &argstr );
- fprintf( out, "\n// SIGNAL %s\n", (const char*)f->name );
+ fprintf( out, "\n// TQ_SIGNAL %s\n", (const char*)f->name );
fprintf( out, "%s %s::%s(", (const char*) f->type,
(const char*)qualifiedClassName(),
(const char*)f->name );
diff --git a/src/moc/moc_yacc.cpp b/src/moc/moc_yacc.cpp
index 85da933d7..ef980dd34 100644
--- a/src/moc/moc_yacc.cpp
+++ b/src/moc/moc_yacc.cpp
@@ -5009,7 +5009,7 @@ void registerClassInNamespace()
}
//
// Remove white space from SIGNAL and SLOT names.
// This function has been copied from qobject.cpp.
//
@@ -6013,7 +6013,7 @@ void generateClass() // generate C++ source code for a class
fixRightAngles( &argstr );
- fprintf( out, "\n// SIGNAL %s\n", (const char*)f->name );
+ fprintf( out, "\n// TQ_SIGNAL %s\n", (const char*)f->name );
fprintf( out, "%s %s::%s(", (const char*) f->type,
(const char*)qualifiedClassName(),
(const char*)f->name );
@@ -5009,7 +5009,7 @@ void registerClassInNamespace()
}
//
-// Remove white space from SIGNAL and SLOT names.
+// Remove white space from TQ_SIGNAL and TQ_SLOT names.
// This function has been copied from qobject.cpp.
//